==> openflowplugin-extension-nicira-0.8.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/get/flow/statistics/output/flow/and/statistics/map/list/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.get.flow.statistics.output.flow.and.statistics.map.list.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-decap-notif-direct-statistics-update-apply-actions-case {
 *   uses nx-action-decap-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/get-flow-statistics/output/flow-and-statistics-map-list/instructions/instruction/instruction/apply-actions-case/apply-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-decap-notif-direct-statistics-update-apply-actions-case</i>
 *
 */
public interface NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase
    extends
    DataObject,
    Augmentable<NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase>,
    NxActionDecapGrouping,
    Action
{



    public static final QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-decap-notif-direct-statistics-update-apply-actions-case");


}

==> openflowplugin-extension-nicira-0.8.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/get/flow/statistics/output/flow/and/statistics/map/list/instructions/instruction/instruction/apply/actions/_case/apply/actions/action/action/NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.get.flow.statistics.output.flow.and.statistics.map.list.instructions.instruction.instruction.apply.actions._case.apply.actions.action.action;
import org.eclipse.jdt.annotation.NonNull;
import org.opendaylight.yang.gen.v1.urn.opendaylight.action.types.rev131112.action.Action;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.$YangModuleInfoImpl;
import org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxActionDecapGrouping;
import org.opendaylight.yangtools.yang.binding.Augmentable;
import org.opendaylight.yangtools.yang.binding.DataObject;
import org.opendaylight.yangtools.yang.common.QName;

/**
 *
 * <p>
 * This class represents the following YANG schema fragment defined in module <b>openflowplugin-extension-nicira-action</b>
 * <pre>
 * case nx-action-decap-notif-direct-statistics-update-apply-actions-case {
 *   uses nx-action-decap-grouping;
 * }
 * </pre>The schema path to identify an instance is
 * <i>openflowplugin-extension-nicira-action/get-flow-statistics/output/flow-and-statistics-map-list/instructions/instruction/instruction/apply-actions-case/apply-actions/action/action/(urn:opendaylight:openflowplugin:extension:nicira:action?revision=2014-07-14)nx-action-decap-notif-direct-statistics-update-apply-actions-case</i>
 *
 */
public interface NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase
    extends
    DataObject,
    Augmentable<NxActionDecapNotifDirectStatisticsUpdateApplyActionsCase>,
    NxActionDecapGrouping,
    Action
{



    public static final @NonNull QName QNAME = $YangModuleInfoImpl.qnameOf("nx-action-decap-notif-direct-statistics-update-apply-actions-case");


}
